@@ -14,9 +14,27 @@ from rich import print as rich_print
 from textfsm import TextFSM
 import pexpect as px
 import transitions
-import snoop
+#import snoop
 
-"""Can't trigger event _go_LOGIN_SUCCESS_UNPRIV from state SEND_LOGIN_PASSWORD!"""
+r""" cannon - Python ssh automation using a single driver
+     Copyright (C) 2020-2021 David Michael Pennington
+
+     This program is free software: you can redistribute it and/or modify
+     it under the terms of the GNU General Public License as published by
+     the Free Software Foundation, either version 3 of the License, or
+     (at your option) any later version.
+
+     This program is distributed in the hope that it will be useful,
+     but WITHOUT ANY WARRANTY; without even the implied warranty of
+     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+     GNU General Public License for more details.
+
+     You should have received a copy of the GNU General Public License
+     along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+     If you need to contact the author, you can do so by emailing:
+     mike [~at~] pennington [/dot\] net
+"""
 
 
 class UnexpectedPrompt(Exception):
@@ -424,6 +442,7 @@ class Shell(transitions.Machine):
         cmd=None,
         template=None,
         prompts=(),
+        timeout=0.0,
         command_timeout=0.0,
         carriage_return=True,
     ):
@@ -432,7 +451,7 @@ class Shell(transitions.Machine):
             - `cmd` is the command to execute
             - `template` is a string with the text of the TextFSM template
             - `prompts` is a tuple of prompt regexs to apply to the output of the command
-            - `command_timeout` is how long we should wait for the command prompt to return
+            - `timeout` is how long we should wait for the command prompt to return
             - `carriage_return` indicates whether the command should be followed with a carriage-return.  The values are either True or False (default is True, meaning the CR will be sent after the command).
 
         execute() returns a list of dicts if `template` is specified; otherwise
@@ -449,10 +468,13 @@ class Shell(transitions.Machine):
                 )
             )
 
-        if command_timeout == 0.0:
-            command_timeout = self.command_timeout
+        if timeout==0.0 and command_timeout > 0.0:
+            timeout = command_timeout
 
-        arg_list = ("cmd", "template", "prompts", "command_timeout", "carriage_return")
+        elif timeout==0.0 and command_timeout == 0.0:
+            timeout = self.command_timeout
+
+        arg_list = ("cmd", "template", "prompts", "timeout", "command_timeout", "carriage_return")
         arg = list()
         if self.debug:
             # build the debugging string...
@@ -465,8 +487,8 @@ class Shell(transitions.Machine):
                     arg.append("template=None")
                 elif ii == "prompts":
                     arg.append("prompts={}".format(prompts))
-                elif ii == "command_timeout":
-                    arg.append("command_timeout={}".format(command_timeout))
+                elif ii == "timeout":
+                    arg.append("timeout={}".format(timeout))
                 elif ii == "carriage_return":
                     arg.append("carriage_return={}".format(carriage_return))
             logstr = ", ".join(arg)
@@ -496,7 +518,7 @@ class Shell(transitions.Machine):
                 )
             )
 
-        index = self.cexpect(cli_prompts, timeout=command_timeout)
+        index = self.cexpect(cli_prompts, timeout=timeout)
 
         if self.debug:
             rich_print(
@@ -504,24 +526,6 @@ class Shell(transitions.Machine):
                 % index
             )
 
-        # Handle sudo password prompt...
-        if False and index == 3:  # TODO remove False (and maybe all this under it)
-            if self.debug:
-                rich_print(
-                    "    [bold blue]Responding to password prompt:[/bold blue] [bold yellow]'{}'[/bold yellow]".format(
-                        self.matching_prompt
-                    )
-                )
-            assert self.password != "", "Hit a password prompt without a password"
-            self.csendline(self.password)
-            if self.debug:
-                rich_print(
-                    "    [bold blue]execute(cmd='{}') sent a password[/bold blue]".format(
-                        cmd
-                    )
-                )
-            index = self.cexpect(cli_prompts, timeout=command_timeout)
-
         ## If template is specified, parse the response into a list of dicts...
         if template is not None:
             if os.path.isfile(str(template)):
@@ -958,7 +962,7 @@ class Shell(transitions.Machine):
                         )
                     )
                     rich_print("        [bold blue]calling cexpect()[/bold blue]")
-                # index = self.child.expect(abbv_prompt_list, timeout=1)
+
                 index = self.child.expect(self.base_prompt_regex, timeout=1)
 
             except px.exceptions.TIMEOUT:
